@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1998-2001 Apple Computer, Inc. All rights reserved.
+ * Copyright (c) 1998-2002 Apple Computer, Inc. All rights reserved.
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
@@ -20,9 +20,18 @@
  * @APPLE_LICENSE_HEADER_END@
  */
 
+//
+//	Includes
+//
+
 // This class' header file
 #include <IOKit/usb/IOUSBMassStorageClass.h>
 
+
+//
+//	Macros
+//
+
 // Macros for printing debugging information
 #if (USB_MASS_STORAGE_DEBUG == 1)
 #define STATUS_LOG(x)	IOLog x
@@ -46,15 +55,27 @@ enum
 
 #pragma mark -
 #pragma mark Protocol Services Methods
+#pragma mark -
+
+//
+//	 AbortSCSICommandForBulkOnlyProtocol - The AbortSCSICommand helper method
+//											for Bulk Only protocol devices.
+//																	[PROTECTED]
+//
 
-// The AbortSCSICommand helper method for Bulk Only protocol devices.
 IOReturn IOUSBMassStorageClass::AbortSCSICommandForBulkOnlyProtocol(
                                         SCSITaskIdentifier request )
 {
 	return kIOReturnError;
 }
 
-// The SendSCSICommand helper method for Bulk Only protocol devices.
+
+//
+//	 SendSCSICommandForBulkOnlyProtocol - 	The SendSCSICommand helper method
+//											for Bulk Only protocol devices.
+//																	[PROTECTED]
+//
+
 IOReturn IOUSBMassStorageClass::SendSCSICommandForBulkOnlyProtocol(
                                          SCSITaskIdentifier request )
 {
@@ -90,6 +111,11 @@ IOReturn IOUSBMassStorageClass::SendSCSICommandForBulkOnlyProtocol(
 #pragma mark -
 #pragma mark Bulk Only Protocol Specific Commands
 
+
+//
+//	 BulkDeviceResetDevice											[PROTECTED]
+//
+
 IOReturn 
 IOUSBMassStorageClass::BulkDeviceResetDevice(
 						BulkOnlyRequestBlock *		boRequestBlock,
@@ -130,6 +156,11 @@ IOUSBMassStorageClass::BulkDeviceResetDevice(
 #pragma mark -
 #pragma mark SendSCSICommand Helper methods
 
+
+//
+//	 BulkOnlyUSBCompletionAction									[PROTECTED]
+//
+
 void 
 IOUSBMassStorageClass::BulkOnlyUSBCompletionAction(
 					                void *			target,
@@ -147,7 +178,13 @@ IOUSBMassStorageClass::BulkOnlyUSBCompletionAction(
 												bufferSizeRemaining );
 }
 
-// Prepare the Command Block Wrapper packet for Bulk Only Protocol
+
+//
+//	 BulkOnlySendCBWPacket -	Prepare the Command Block Wrapper packet for
+//								Bulk Only Protocol
+//																	[PROTECTED]
+//
+
 IOReturn 
 IOUSBMassStorageClass::BulkOnlySendCBWPacket(
 						BulkOnlyRequestBlock *		boRequestBlock,
@@ -210,6 +247,11 @@ IOUSBMassStorageClass::BulkOnlySendCBWPacket(
 	return status;
 }
 
+
+//
+//	 BulkOnlyTransferData											[PROTECTED]
+//
+
 IOReturn 
 IOUSBMassStorageClass::BulkOnlyTransferData( 
 						BulkOnlyRequestBlock *		boRequestBlock,
@@ -227,6 +269,7 @@ IOUSBMassStorageClass::BulkOnlyTransferData(
 					GetDataBuffer( boRequestBlock->request ), 
 					GetTimeoutDuration( boRequestBlock->request ),  // Use the client's timeout for both
 					GetTimeoutDuration( boRequestBlock->request ),
+					GetRequestedDataTransferCount( boRequestBlock->request ),
 					&boRequestBlock->boCompletion );
 	}
 	else if (GetDataTransferDirection(boRequestBlock->request) == kSCSIDataTransfer_FromInitiatorToTarget)
@@ -235,6 +278,7 @@ IOUSBMassStorageClass::BulkOnlyTransferData(
 					GetDataBuffer( boRequestBlock->request ), 
 					GetTimeoutDuration( boRequestBlock->request ),  // Use the client's timeout for both
 					GetTimeoutDuration( boRequestBlock->request ),
+					GetRequestedDataTransferCount( boRequestBlock->request ),
 					&boRequestBlock->boCompletion );
 	}
 
@@ -244,7 +288,14 @@ IOUSBMassStorageClass::BulkOnlyTransferData(
 	return status;
 }
 
-// Prepare the Command Status Wrapper packet for Bulk Only Protocol
+
+//
+//	 BulkOnlyReceiveCSWPacket -	Prepare the Command Status Wrapper packet
+//									for Bulk Only Protocol
+//																	[PROTECTED]
+//
+
+// 
 IOReturn 
 IOUSBMassStorageClass::BulkOnlyReceiveCSWPacket(
 						BulkOnlyRequestBlock *		boRequestBlock,
@@ -275,6 +326,11 @@ IOUSBMassStorageClass::BulkOnlyReceiveCSWPacket(
 	return status;
 }
 
+
+//
+//	 BulkOnlyExecuteCommandCompletion								[PROTECTED]
+//
+
 void 
 IOUSBMassStorageClass::BulkOnlyExecuteCommandCompletion(
 						BulkOnlyRequestBlock *	boRequestBlock,
